@@ -24,6 +24,7 @@
 
 #ifdef HAVE_MYSQL
 #include <mysql/testutils/mysql_schema.h>
+#include <hooks/dhcp/mysql/mysql_lease_mgr.h>
 #endif
 
 #include <log/logger_support.h>
@@ -47,6 +48,7 @@ using namespace isc;
 using namespace isc::asiolink;
 using namespace isc::config;
 using namespace isc::data;
+using namespace isc::db;
 
 #ifdef HAVE_MYSQL
 using namespace isc::db::test;
@@ -176,7 +178,7 @@ typedef boost::shared_ptr<TestCBControlDHCPv4> TestCBControlDHCPv4Ptr;
 ///
 /// Exposes internal fields and installs stub implementation of the
 /// @c CBControlDHCPv4 object.
-class NakedControlledDhcpv4Srv: public ControlledDhcpv4Srv {
+class NakedControlledDhcpv4Srv : public ControlledDhcpv4Srv {
 public:
 
     /// @brief Constructor.
@@ -188,7 +190,7 @@ public:
     }
 };
 
-/// @brief test class for Kea configuration backend
+/// @brief test class for Kea configuration backend.
 ///
 /// This class is used for testing Kea configuration backend.
 /// It is very simple and currently focuses on reading
@@ -301,7 +303,6 @@ public:
         EXPECT_EQ(0, cb_control->getDatabaseCurrentConfigFetchCalls());
         EXPECT_EQ(1, cb_control->getDatabaseStagingConfigFetchCalls());
 
-
         if (call_command) {
             // The case where there is no backend is tested in the
             // controlled server tests so we have only to verify
@@ -1001,6 +1002,9 @@ public:
     /// reconfiguration.
     void testBackendReconfiguration(const std::string& backend_first,
                                     const std::string& backend_second);
+
+    /// @brief Initializer.
+    MySqlLeaseMgrInit init_;
 };
 
 std::string
@@ -1079,7 +1083,6 @@ testBackendReconfiguration(const std::string& backend_first,
               LeaseMgrFactory::instance().getType());
 }
 
-
 // This test verifies that backend specification can be added on
 // server reconfiguration.
 TEST_F(JSONFileBackendMySQLTest, reconfigureBackendUndefinedToMySQL) {
