@@ -52,7 +52,7 @@ namespace {
     "  s.interface_id_4o6," \
     "  s.subnet_4o6," \
     "  s.boot_file_name," \
-    "  s.client_class," \
+    "  s.client_classes," \
     "  s.interface," \
     "  s.match_client_id," \
     "  gmt_epoch(s.modification_ts) as modification_ts, " \
@@ -105,7 +105,7 @@ namespace {
     "  s.authoritative," \
     "  s.min_valid_lifetime," \
     "  s.max_valid_lifetime," \
-    "  p.client_class," \
+    "  p.client_classes," \
     "  p.evaluate_additional_classes," \
     "  p.user_context," \
     "  s.ddns_send_updates," \
@@ -159,7 +159,7 @@ namespace {
     "SELECT" \
     "  s.subnet_id," \
     "  s.subnet_prefix," \
-    "  s.client_class," \
+    "  s.client_classes," \
     "  s.interface," \
     "  gmt_epoch(s.modification_ts) as modification_ts, " \
     "  s.preferred_lifetime," \
@@ -236,12 +236,12 @@ namespace {
     "  s.max_preferred_lifetime," \
     "  s.min_valid_lifetime," \
     "  s.max_valid_lifetime," \
-    "  p.client_class," \
+    "  p.client_classes," \
     "  p.evaluate_additional_classes," \
     "  p.user_context," \
     "  d.excluded_prefix," \
     "  d.excluded_prefix_length," \
-    "  d.client_class," \
+    "  d.client_classes," \
     "  d.evaluate_additional_classes," \
     "  d.user_context," \
     "  s.ddns_send_updates," \
@@ -299,7 +299,7 @@ namespace {
       "  p.start_address," \
       "  p.end_address," \
       "  p.subnet_id," \
-      "  p.client_class," \
+      "  p.client_classes," \
       "  p.evaluate_additional_classes," \
       "  p.user_context," \
       "  gmt_epoch(p.modification_ts) as modification_ts, " \
@@ -341,7 +341,7 @@ namespace {
     "  p.start_address," \
     "  p.end_address," \
     "  p.subnet_id," \
-    "  p.client_class," \
+    "  p.client_classes," \
     "  p.evaluate_additional_classes," \
     "  p.user_context," \
     "  gmt_epoch(p.modification_ts) as modification_ts, " \
@@ -387,7 +387,7 @@ namespace {
     "  p.subnet_id," \
     "  p.excluded_prefix," \
     "  p.excluded_prefix_length," \
-    "  p.client_class," \
+    "  p.client_classes," \
     "  p.evaluate_additional_classes," \
     "  p.user_context," \
     "  gmt_epoch(p.modification_ts) as modification_ts, " \
@@ -428,7 +428,7 @@ namespace {
     "SELECT" \
     "  n.id," \
     "  n.name," \
-    "  n.client_class," \
+    "  n.client_classes," \
     "  n.interface," \
     "  n.match_client_id," \
     "  gmt_epoch(n.modification_ts) as modification_ts, " \
@@ -511,7 +511,7 @@ namespace {
     "SELECT" \
     "  n.id," \
     "  n.name," \
-    "  n.client_class," \
+    "  n.client_classes," \
     "  n.interface," \
     "  gmt_epoch(n.modification_ts) as modification_ts, " \
     "  n.preferred_lifetime," \
@@ -856,7 +856,7 @@ namespace {
     "  start_address," \
     "  end_address," \
     "  subnet_id," \
-    "  client_class," \
+    "  client_classes," \
     "  evaluate_additional_classes," \
     "  user_context," \
     "  modification_ts" \
@@ -872,7 +872,7 @@ namespace {
     "  subnet_id," \
     "  excluded_prefix," \
     "  excluded_prefix_length," \
-    "  client_class," \
+    "  client_classes," \
     "  evaluate_additional_classes," \
     "  user_context," \
     "  modification_ts" \
