@@ -292,6 +292,14 @@ ClientClassDefParser::parse(ClientClassDictionaryPtr& class_dictionary,
         // depend_on_known is now allowed
     }
 
+    if (additional && 
+        (!valid_lft.unspecified() ||
+         !preferred_lft.unspecified() ||
+         !offer_lft.unspecified())) {
+        LOG_WARN(dhcpsrv_logger, DHCPSRV_CLASS_WITH_ADDITIONAL_AND_LIFETIMES)
+            .arg(name);
+    }
+
     // Add the client class definition
     try {
         class_dictionary->addClass(name, match_expr, test, additional,
