@@ -412,7 +412,7 @@ SrvConfig::updateStatistics() {
     // a lease manager, such as D2. @todo We should probably examine why
     // "SrvConfig" is being used by D2.
     if (LeaseMgrFactory::haveInstance()) {
-        // Updates  statistics for v4 and v6 subnets
+        // Updates statistics for v4 and v6 subnets.
         getCfgSubnets4()->updateStatistics();
         getCfgSubnets6()->updateStatistics();
     }
@@ -942,15 +942,15 @@ SrvConfig::toElement() const {
 }
 
 DdnsParamsPtr
-SrvConfig::getDdnsParams(const Subnet4Ptr& subnet) const {
+SrvConfig::getDdnsParams(const ConstSubnet4Ptr& subnet) const {
     return (DdnsParamsPtr(new DdnsParams(subnet,
                                          getD2ClientConfig()->getEnableUpdates())));
 }
 
 DdnsParamsPtr
-SrvConfig::getDdnsParams(const Subnet6Ptr& subnet) const {
-   return(DdnsParamsPtr(new DdnsParams(subnet,
-                                       getD2ClientConfig()->getEnableUpdates())));
+SrvConfig::getDdnsParams(const ConstSubnet6Ptr& subnet) const {
+    return (DdnsParamsPtr(new DdnsParams(subnet,
+                                         getD2ClientConfig()->getEnableUpdates())));
 }
 
 void
