@@ -27,6 +27,9 @@ extern const isc::log::MessageID HTTP_CONNECTION_SHUTDOWN;
 extern const isc::log::MessageID HTTP_CONNECTION_SHUTDOWN_FAILED;
 extern const isc::log::MessageID HTTP_CONNECTION_STOP;
 extern const isc::log::MessageID HTTP_CONNECTION_STOP_FAILED;
+extern const isc::log::MessageID HTTP_CONNECTION_WATCH_SOCKET_CLEAR_ERROR;
+extern const isc::log::MessageID HTTP_CONNECTION_WATCH_SOCKET_CLOSE_ERROR;
+extern const isc::log::MessageID HTTP_CONNECTION_WATCH_SOCKET_MARK_READY_ERROR;
 extern const isc::log::MessageID HTTP_DATA_RECEIVED;
 extern const isc::log::MessageID HTTP_IDLE_CONNECTION_TIMEOUT_OCCURRED;
 extern const isc::log::MessageID HTTP_PREMATURE_CONNECTION_TIMEOUT_OCCURRED;
