@@ -1,10 +1,11 @@
-// Copyright (C) 2014-2021 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2014-2024 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
 // file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
 #include <config.h>
+
 #include <cc/data.h>
 #include <process/daemon.h>
 #include <process/log_parser.h>
@@ -12,15 +13,17 @@
 #include <log/logger_name.h>
 #include <log/logger_support.h>
 #include <process/config_base.h>
-#include <util/filename.h>
+#include <process/redact_config.h>
+#include <util/filesystem.h>
 
 #include <functional>
 #include <sstream>
 #include <fstream>
+
 #include <errno.h>
 
 using namespace isc::data;
-namespace ph = std::placeholders;
+using namespace isc::util::file;
 
 /// @brief provides default implementation for basic daemon operations
 ///
@@ -84,11 +87,10 @@ Daemon::getVerbose() {
 
 void Daemon::loggerInit(const char* name, bool verbose) {
 
-    setenv("KEA_LOGGER_DESTINATION",  "stdout", 0);
+    setenv("KEA_LOGGER_DESTINATION", "stdout", 0);
 
     // Initialize logger system
-    isc::log::initLogger(name, isc::log::DEBUG, isc::log::MAX_DEBUG_LEVEL,
-                         NULL);
+    isc::log::initLogger(name, isc::log::DEBUG, isc::log::MAX_DEBUG_LEVEL, 0);
 
     // Apply default configuration (log INFO or DEBUG to stdout)
     isc::log::setDefaultLoggingOutput(verbose);
@@ -114,10 +116,10 @@ Daemon::checkConfigFile() const {
         isc_throw(isc::BadValue, "config file name is not set");
     }
 
-    // Create Filename instance from the config_file_ pathname, and
+    // Create Path instance from the config_file_ pathname, and
     // check the file name component.
-    isc::util::Filename file(config_file_);
-    if (file.name().empty()) {
+    Path file(config_file_);
+    if (file.stem().empty()) {
         isc_throw(isc::BadValue, "config file:" << config_file_
                   << " is missing file name");
     }
@@ -126,7 +128,7 @@ Daemon::checkConfigFile() const {
 std::string
 Daemon::getProcName() {
     return (proc_name_);
-};
+}
 
 void
 Daemon::setProcName(const std::string& proc_name) {
@@ -150,7 +152,7 @@ Daemon::getPIDFileName() const {
     }
 
     return ("");
-};
+}
 
 void
 Daemon::setPIDFileName(const std::string& pid_file_name) {
@@ -165,7 +167,7 @@ Daemon::setPIDFileName(const std::string& pid_file_name) {
     }
 
     pid_file_.reset(new util::PIDFile(pid_file_name));
-};
+}
 
 std::string
 Daemon::makePIDFileName() const {
@@ -174,10 +176,10 @@ Daemon::makePIDFileName() const {
                   "Daemon::makePIDFileName config file name is not set");
     }
 
-    // Create Filename instance from the config_file_ pathname, so we can
+    // Create Path instance from the config_file_ pathname, so we can
     // extract the fname component.
-    isc::util::Filename file(config_file_);
-    if (file.name().empty()) {
+    Path file(config_file_);
+    if (file.stem().empty()) {
         isc_throw(isc::BadValue, "Daemon::makePIDFileName config file:"
                   << config_file_ << " is missing file name");
     }
@@ -190,7 +192,7 @@ Daemon::makePIDFileName() const {
     // Make the pathname for the PID file from the runtime directory,
     // configuration name and process name.
     std::ostringstream stream;
-    stream  << pid_file_dir_ << "/" << file.name()
+    stream  << pid_file_dir_ << "/" << file.stem()
             << "." << proc_name_ << ".pid";
 
     return(stream.str());
@@ -229,6 +231,9 @@ Daemon::writeConfigFile(const std::string& config_file,
         isc_throw(Unexpected, "Can't write configuration: conversion to JSON failed");
     }
 
+    // Remove rights for other from the umask.
+    Umask mask(S_IRWXO);
+
     std::ofstream out(config_file, std::ios::trunc);
     if (!out.good()) {
         isc_throw(Unexpected, "Unable to open file " + config_file + " for writing");
@@ -244,5 +249,20 @@ Daemon::writeConfigFile(const std::string& config_file,
     return (bytes);
 }
 
+std::list<std::list<std::string>>
+Daemon::jsonPathsToRedact() const {
+    static std::list<std::list<std::string>> const list;
+    return list;
 }
+
+isc::data::ConstElementPtr
+Daemon::redactConfig(isc::data::ConstElementPtr const& config) {
+    isc::data::ConstElementPtr result(config);
+    for (std::list<std::string>& json_path : jsonPathsToRedact()) {
+        result = isc::process::redactConfig(result, json_path);
+    }
+    return result;
 }
+
+}  // namespace process
+}  // namespace isc
